@@ -23,3 +23,15 @@ class NoMoreRecordsError(SruthiError):
     This error is raised if all records have been loaded (or no records are
     present)
     """
+
+
+class SruthiWarning(Warning):
+    """
+    General sruthi warning class to provide a superclass for all warnings
+    """
+
+
+class WrongNamespaceWarning(SruthiWarning):
+    """
+    A warning to indicate, that a server uses the wrong SRU namespace.
+    """
